Oneshot

Struct Oneshot 

pub struct Oneshot<I, O>(/* private fields */);
Invoke and Accept implementation in terms of a single stream pair.

Either Invoke::invoke or Accept::accept can only be called at most once on Oneshot, repeated calls with return an error

Implementations

Source

impl Oneshot<ReadHalf<DuplexStream>, WriteHalf<DuplexStream>>

pub fn duplex(max_buf_size: usize) -> (Self, Self)

Creates a pair of connected Oneshot using tokio::io::duplex.

Source

impl<I, O> Oneshot<I, O>

pub fn try_take_inner(&self) -> Result<(I, O)>

Returns the inner stream pair if Oneshot has not been used yet or an error.

Source

impl Oneshot<OwnedReadHalf, OwnedWriteHalf>

pub fn unix_pair() -> Result<(Oneshot, Oneshot)>

Creates a pair of connected Oneshot using UnixStream::pair.