pub struct Oneshot<I, O>(/* private fields */);Expand description
Invoke and Accept implementation in terms of a single stream pair.
Either Invoke::invoke or Accept::accept can only be called at most once
on Oneshot, repeated calls with return an error
Implementations
Sourceimpl Oneshot<ReadHalf<DuplexStream>, WriteHalf<DuplexStream>>
impl Oneshot<ReadHalf<DuplexStream>, WriteHalf<DuplexStream>>
Sourcepub fn duplex(max_buf_size: usize) -> (Self, Self)
pub fn duplex(max_buf_size: usize) -> (Self, Self)
Creates a pair of connected Oneshot using tokio::io::duplex.
Sourceimpl<I, O> Oneshot<I, O>
impl<I, O> Oneshot<I, O>
Sourcepub fn try_take_inner(&self) -> Result<(I, O)>
pub fn try_take_inner(&self) -> Result<(I, O)>
Returns the inner stream pair if Oneshot has not been used yet or an error.